@@ -1,20 +1,7 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "genericlayout.h"
@@ -1514,38 +1501,19 @@ QList<int> GenericLayout::subContainmentsOf(Plasma::Containment *containment) co
     return subs;
 }
 
-QList<int> GenericLayout::viewsScreens()
+QList<int> GenericLayout::viewsExplicitScreens()
 {
+    Data::ViewsTable views = viewsTable();
     QList<int> screens;
 
-    if (isActive()) {
-        for (const auto containment : m_containments) {
-            if (Layouts::Storage::self()->isLatteContainment(containment)) {
-                int screenId{Layouts::Storage::IDNULL};
-
-                //! valid screen id
-                if (latteViewExists(containment)) {
-                    screenId = m_latteViews[containment]->positioner()->currentScreenId();
-                } else {
-                    screenId = containment->screen();
-
-                    if (!Layouts::Storage::isValid(screenId)) {
-                        screenId = containment->lastScreen();
-                    }
-                }
-
-                if (Layouts::Storage::isValid(screenId) && !screens.contains(screenId)) {
-                    screens << screenId;
-                }
-            }
+    for (int i=0; i<views.rowCount(); ++i) {
+        if (!views[i].onPrimary && !screens.contains(views[i].screen)) {
+            screens << views[i].screen;
         }
-
-        return screens;
-    } else {
-        return Layouts::Storage::self()->viewsScreens(file());
     }
-}
 
+    return screens;
+}
 
 //! STORAGE
 
