@@ -1,24 +1,12 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "trackedgeneralinfo.h"
 
+#include <QLatin1String>
+
 //local
 #include "windowstracker.h"
 #include "../abstractwindowinterface.h"
@@ -117,7 +105,7 @@ bool TrackedGeneralInfo::isTrackingCurrentActivity() const
 
 void TrackedGeneralInfo::updateTrackingCurrentActivity()
 {
-    m_isTrackingCurrentActivity = ( m_activities.isEmpty() || m_activities[0] == "{0}" || m_activities.contains(m_wm->currentActivity()));
+    m_isTrackingCurrentActivity = ( m_activities.isEmpty() || m_activities[0] == QLatin1String("{0}") || m_activities.contains(m_wm->currentActivity()));
 }
 
 
